(v1.7.1)=
### 1.7.1 {small}`2021-02-24`

#### Documentation

- More twitter handles for core devs {pr}`1676` {smaller}`G Eraslan`

#### Bug fixes

- {func}`~scanpy.tl.dendrogram` use `1 - correlation` as distance matrix to compute the dendrogram {pr}`1614` {smaller}`F Ramirez`
- Fixed {func}`~scanpy.get.obs_df`/ {func}`~scanpy.get.var_df` erroring when `keys` not passed {pr}`1637` {smaller}`I Virshup`
- Fixed argument handling for {func}`scanpy.pp.scrublet` {smaller}`J Manning`
- Fixed passing of `kwargs` to {func}`scanpy.pl.violin` when `stripplot` was also used {pr}`1655` {smaller}`M van den Beek`
- Fixed colorbar creation in `scanpy.pl.timeseries_as_heatmap` {pr}`1654` {smaller}`M van den Beek`
